==> gorilla-notes-0.3.0-20200818.200253-6.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$players$SoundCloud.js <==
shadow$provide.module$node_modules$react_player$lib$players$SoundCloud=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===
Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:
{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=
!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,
NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,
[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,
configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value:value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=exports.SoundCloud=void 0;
var _react=function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,
key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),_utils=require("module$node_modules$react_player$lib$utils");global=function(obj){return obj&&obj.__esModule?obj:{"default":obj}}(require("module$node_modules$react_player$lib$singlePlayer"));var MATCH_URL=/(?:soundcloud\.com|snd\.sc)\/[^.]+$/;require=function(_Component){function SoundCloud(){if(!(this instanceof SoundCloud))throw new TypeError("Cannot call a class as a function");
for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_super.call.apply(_super,[this].concat(args));_defineProperty(_assertThisInitialized(_this),"callPlayer",_utils.callPlayer);_defineProperty(_assertThisInitialized(_this),"duration",null);_defineProperty(_assertThisInitialized(_this),"currentTime",null);_defineProperty(_assertThisInitialized(_this),"fractionLoaded",null);_defineProperty(_assertThisInitialized(_this),"mute",function(){_this.setVolume(0)});
_defineProperty(_assertThisInitialized(_this),"unmute",function(){null!==_this.props.volume&&_this.setVolume(_this.props.volume)});_defineProperty(_assertThisInitialized(_this),"ref",function(iframe){_this.iframe=iframe});return _this}_inherits(SoundCloud,_Component);var _super=_createSuper(SoundCloud);_createClass(SoundCloud,[{key:"load",value:function(url,isReady){var _this2=this;(0,_utils.getSDK)("https://w.soundcloud.com/player/api.js","SC").then(function(SC){if(_this2.iframe){var _SC$Widget$Events=
SC.Widget.Events,PLAY=_SC$Widget$Events.PLAY,PLAY_PROGRESS=_SC$Widget$Events.PLAY_PROGRESS,PAUSE=_SC$Widget$Events.PAUSE,FINISH=_SC$Widget$Events.FINISH;_SC$Widget$Events=_SC$Widget$Events.ERROR;isReady||(_this2.player=SC.Widget(_this2.iframe),_this2.player.bind(PLAY,_this2.props.onPlay),_this2.player.bind(PAUSE,_this2.props.onPause),_this2.player.bind(PLAY_PROGRESS,function(e){_this2.currentTime=e.currentPosition/1E3;_this2.fractionLoaded=e.loadedProgress}),_this2.player.bind(FINISH,function(){return _this2.props.onEnded()}),
_this2.player.bind(_SC$Widget$Events,function(e){return _this2.props.onError(e)}));_this2.player.load(url,_objectSpread({},_this2.props.config.soundcloud.options,{callback:function(){_this2.player.getDuration(function(duration){_this2.duration=duration/1E3;_this2.props.onReady()})}}))}})}},{key:"play",value:function(){this.callPlayer("play")}},{key:"pause",value:function(){this.callPlayer("pause")}},{key:"stop",value:function(){}},{key:"seekTo",value:function(seconds){this.callPlayer("seekTo",1E3*
seconds)}},{key:"setVolume",value:function(fraction){this.callPlayer("setVolume",100*fraction)}},{key:"getDuration",value:function(){return this.duration}},{key:"getCurrentTime",value:function(){return this.currentTime}},{key:"getSecondsLoaded",value:function(){return this.fractionLoaded*this.duration}},{key:"render",value:function(){var style={width:"100%",height:"100%",display:this.props.display};return _react["default"].createElement("iframe",{ref:this.ref,src:"https://w.soundcloud.com/player/?url\x3d".concat(encodeURIComponent(this.props.url)),
style:style,frameBorder:0,allow:"autoplay"})}}]);return SoundCloud}(_react.Component);exports.SoundCloud=require;_defineProperty(require,"displayName","SoundCloud");_defineProperty(require,"canPlay",function(url){return MATCH_URL.test(url)});_defineProperty(require,"loopOnEnded",!0);global=(0,global["default"])(require);exports["default"]=global}
//# sourceMappingURL=module$node_modules$react_player$lib$players$SoundCloud.js.map

==> gorilla-notes-0.4.0-20200914.094953-4.jar: public/js/compiled/cljs-runtime/module$node_modules$react_player$lib$players$SoundCloud.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_player$lib$players$SoundCloud=function(global,require,module,exports){function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===
Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:
{};i%2?ownKeys(Object(source),!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=
!0;"value"in descriptor&&(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _createSuper(Derived){return function(){var Super=_getPrototypeOf(Derived);if(_isNativeReflectConstruct()){var NewTarget=_getPrototypeOf(this).constructor;Super=Reflect.construct(Super,arguments,
NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,
[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,{constructor:{value:subClass,writable:!0,
configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});exports["default"]=exports.SoundCloud=void 0;var _react=
function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{"default":obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,
key,desc):newObj[key]=obj[key]}newObj["default"]=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index")),_utils=require("module$node_modules$react_player$lib$utils");global=function(obj){return obj&&obj.__esModule?obj:{"default":obj}}(require("module$node_modules$react_player$lib$singlePlayer"));var MATCH_URL=/(?:soundcloud\.com|snd\.sc)\/[^.]+$/;require=function(_Component){function SoundCloud(){if(!(this instanceof SoundCloud))throw new TypeError("Cannot call a class as a function");
for(var _len=arguments.length,args=Array(_len),_key=0;_key<_len;_key++)args[_key]=arguments[_key];var _this=_super.call.apply(_super,[this].concat(args));_defineProperty(_assertThisInitialized(_this),"callPlayer",_utils.callPlayer);_defineProperty(_assertThisInitialized(_this),"duration",null);_defineProperty(_assertThisInitialized(_this),"currentTime",null);_defineProperty(_assertThisInitialized(_this),"fractionLoaded",null);_defineProperty(_assertThisInitialized(_this),"mute",function(){_this.setVolume(0)});
_defineProperty(_assertThisInitialized(_this),"unmute",function(){null!==_this.props.volume&&_this.setVolume(_this.props.volume)});_defineProperty(_assertThisInitialized(_this),"ref",function(iframe){_this.iframe=iframe});return _this}_inherits(SoundCloud,_Component);var _super=_createSuper(SoundCloud);_createClass(SoundCloud,[{key:"load",value:function(url,isReady){var _this2=this;(0,_utils.getSDK)("https://w.soundcloud.com/player/api.js","SC").then(function(SC){if(_this2.iframe){var _SC$Widget$Events=
SC.Widget.Events,PLAY=_SC$Widget$Events.PLAY,PLAY_PROGRESS=_SC$Widget$Events.PLAY_PROGRESS,PAUSE=_SC$Widget$Events.PAUSE,FINISH=_SC$Widget$Events.FINISH;_SC$Widget$Events=_SC$Widget$Events.ERROR;isReady||(_this2.player=SC.Widget(_this2.iframe),_this2.player.bind(PLAY,_this2.props.onPlay),_this2.player.bind(PAUSE,_this2.props.onPause),_this2.player.bind(PLAY_PROGRESS,function(e){_this2.currentTime=e.currentPosition/1E3;_this2.fractionLoaded=e.loadedProgress}),_this2.player.bind(FINISH,function(){return _this2.props.onEnded()}),
_this2.player.bind(_SC$Widget$Events,function(e){return _this2.props.onError(e)}));_this2.player.load(url,_objectSpread({},_this2.props.config.soundcloud.options,{callback:function(){_this2.player.getDuration(function(duration){_this2.duration=duration/1E3;_this2.props.onReady()})}}))}})}},{key:"play",value:function(){this.callPlayer("play")}},{key:"pause",value:function(){this.callPlayer("pause")}},{key:"stop",value:function(){}},{key:"seekTo",value:function(seconds){this.callPlayer("seekTo",1E3*
seconds)}},{key:"setVolume",value:function(fraction){this.callPlayer("setVolume",100*fraction)}},{key:"getDuration",value:function(){return this.duration}},{key:"getCurrentTime",value:function(){return this.currentTime}},{key:"getSecondsLoaded",value:function(){return this.fractionLoaded*this.duration}},{key:"render",value:function(){var style={width:"100%",height:"100%",display:this.props.display};return _react["default"].createElement("iframe",{ref:this.ref,src:"https://w.soundcloud.com/player/?url\x3d".concat(encodeURIComponent(this.props.url)),
style,frameBorder:0,allow:"autoplay"})}}]);return SoundCloud}(_react.Component);exports.SoundCloud=require;_defineProperty(require,"displayName","SoundCloud");_defineProperty(require,"canPlay",function(url){return MATCH_URL.test(url)});_defineProperty(require,"loopOnEnded",!0);global=(0,global["default"])(require);exports["default"]=global}
//# sourceMappingURL=module$node_modules$react_player$lib$players$SoundCloud.js.map
